pub fn parse_namespace(
namespaces: &FxHashMap<Prefix, Namespace>,
input: &mut Parser<'_>,
) -> Result<(Prefix, ParsedNamespace), ParseError>Expand description
Try to parse a namespace and return it if parsed, or none if there was not one present